@@ -40,14 +40,26 @@ fn print_board(stdout: &mut RawTerminal<Stdout>, board: &Vec<Vec<i32>>) {
     }
 }
 fn main() {
-    let mut keys = stdin().keys();
-    let mut stdout = stdout().into_raw_mode().unwrap();
-
     // Initializes the game
-    let mut game = Game::new(2, 8);
+    macro_rules! input {
+        ($msg: expr) => {{
+            let mut input = String::new();
+            print!("{}", $msg);
+            stdout().flush().unwrap();
+            stdin().read_line(&mut input).expect("Error reading input");
+            input.trim().parse().unwrap()
+        }};
+    }
+    let board_size: usize = input!("Input board size: ");
+    let winning: i32 = input!("Input winning number: ");
+
+    let mut game = Game::new(board_size, winning);
 
     let mut valid_move = true;
 
+    let mut keys = stdin().keys();
+    let mut stdout = stdout().into_raw_mode().unwrap();
+
     loop {
         if valid_move {
             game.refresh();
